@@ -471,19 +471,6 @@ draw_action_volume (MsdMediaKeysWindow *window,
         volume_box_x0 = round (icon_box_x0);
         volume_box_y0 = round (icon_box_height + icon_box_y0);
 
-#if 0
-        g_message ("icon box: w=%f h=%f _x0=%f _y0=%f",
-                   icon_box_width,
-                   icon_box_height,
-                   icon_box_x0,
-                   icon_box_y0);
-        g_message ("volume box: w=%f h=%f _x0=%f _y0=%f",
-                   volume_box_width,
-                   volume_box_height,
-                   volume_box_x0,
-                   volume_box_y0);
-#endif
-
         res = render_speaker (window,
                               cr,
                               icon_box_x0, icon_box_y0,
@@ -499,14 +486,6 @@ draw_action_volume (MsdMediaKeysWindow *window,
                 speaker_cx = icon_box_x0 + speaker_width / 2;
                 speaker_cy = icon_box_y0 + speaker_height / 2;
 
-#if 0
-                g_message ("speaker box: w=%f h=%f cx=%f cy=%f",
-                           speaker_width,
-                           speaker_height,
-                           speaker_cx,
-                           speaker_cy);
-#endif
-
                 /* draw speaker symbol */
                 draw_speaker (cr, speaker_cx, speaker_cy, speaker_width, speaker_height);
 
@@ -608,19 +587,6 @@ draw_action_custom (MsdMediaKeysWindow *window,
         bright_box_x0 = round (icon_box_x0);
         bright_box_y0 = round (icon_box_height + icon_box_y0);
 
-#if 0
-        g_message ("icon box: w=%f h=%f _x0=%f _y0=%f",
-                   icon_box_width,
-                   icon_box_height,
-                   icon_box_x0,
-                   icon_box_y0);
-        g_message ("brightness box: w=%f h=%f _x0=%f _y0=%f",
-                   bright_box_width,
-                   bright_box_height,
-                   bright_box_x0,
-                   bright_box_y0);
-#endif
-
         res = render_custom (window,
                              cr,
                              icon_box_x0, icon_box_y0,
